# KIB Package
Berechnungstool für konstruktiven Ingenieurbau. In der derzeitigen Version sind verschiedene Berechnungstools enthalten:
- Betonbau: Bemessungstools für den konstruktiven Betonbau nach DIN EN 1992
- Plattenbeulen: Eigenwertermittlung von einfachen, rechteckigen Beulfeldern nach dem Ritz'schen Verfahren  für übliche Randlagerungen (Gelenkig, Frei, Eingespannt)
- Plattentragwerke: Berechnung linearer Plattentragwerke nach dem Ritz'schen Verfahren für übliche Randlagerungen (Gelenkig, Eingespannt)
- Querschnittswerte: Berechnungstool für die Berechnung der Querschnittswerte von dünnwandigen Querschnitten, inklusive der 
Ermittlung des Schubmittelpunkts und sekundärer Torsionskennwerte für nicht-wölbfreie Querschnitte
- STABRAUM: 3D Stabwerkprogramm mit Wölbkrafttorsion


## Betonbau 